@@ -77,10 +77,6 @@ char *fake = N_("Calculate the kth compund matrix of A");
 char *fake = N_("Delete a column of a matrix");
 char *fake = N_("Delete a row of a matrix");
 char *fake = N_("Get the dot product of two vectors (no conjugates)");
-char *fake = N_("Is a matrix diagonal");
-char *fake = N_("Is a matrix lower triangular");
-char *fake = N_("Is a matrix upper triangular");
-char *fake = N_("Is argument a horizontal or a vertical vector");
 char *fake = N_("Zero out entries above the diagonal");
 char *fake = N_("Make diagonal matrix from a vector");
 char *fake = N_("Make column vector out of matrix by putting columns above each other");
@@ -142,6 +138,7 @@ char *fake = N_("Projection of vector v onto subspace W given a sesquilinear for
 char *fake = N_("Get the QR decomposition of A, returns R and Q can be a reference");
 char *fake = N_("Get the rank of a matrix");
 char *fake = N_("Return the Rayleigh quotient of a matrix and a vector");
+char *fake = N_("Compute an eigenvalue using the Rayleigh Quotient Iteration method until we are epsilon from eigenvalue or for maxiter iterations");
 char *fake = N_("Rosser matrix, a classic symmetric eigenvalue test problem");
 char *fake = N_("Rotation around origin in R^2");
 char *fake = N_("Rotation around origin in R^3 about the x-axis");
@@ -167,16 +164,19 @@ char *fake = N_("Double factorial: n(n-2)(n-4)...");
 char *fake = N_("Factorial: n(n-1)(n-2)...");
 char *fake = N_("Falling factorial: (n)_k = n(n-1)...(n-(k-1))");
 char *fake = N_("Calculate n'th fibbonachi number");
+char *fake = N_("Calculate the Frobenius number for a coin problem");
 char *fake = N_("Galois matrix given a linear combining rule (a_1*x_+...+a_n*x_n=x_(n+1))");
+char *fake = N_("Use greedy algorithm to find c, for c . v = n.  (v must be sorted)");
 char *fake = N_("Harmonic Number, the nth harmonic number of order r");
 char *fake = N_("Hofstadter's function q(n) defined by q(1)=1, q(2)=1, q(n)=q(n-q(n-1))+q(n-q(n-2))");
 char *fake = N_("Compute linear recursive sequence using galois stepping");
 char *fake = N_("Calculate multinomial coefficients");
 char *fake = N_("Get the pascal's triangle as a matrix");
-char *fake = N_("(Puchhammer) Rising factorial: (n)_k = n(n+1)...(n+(k-1))");
+char *fake = N_("(Pochhammer) Rising factorial: (n)_k = n(n+1)...(n+(k-1))");
+char *fake = N_("Stirling number of the first kind");
+char *fake = N_("Stirling number of the second kind");
 char *fake = N_("Subfactorial: n! times sum_{k=1}^n (-1)^k/k!");
 char *fake = N_("Calculate the nth triangular number");
-char *fake = N_("Calculate combinations (binomial coefficient)");
 char *fake = N_("Calculate permutations");
 char *fake = N_("Integration of f by Composite Simpson's Rule on the interval [a,b] with the number of steps calculated by the fourth derivative bound and the desired tolerance");
 char *fake = N_("Attempt to calculate derivative by trying first symbolically and then numerically");
